﻿using System;
using Dapper;
using System.Data.SqlClient;
using System.Configuration;
using System.Collections;
using System.Linq;

namespace Usando_Dapper
{
    class Program
    {
        static string strConexao = ConfigurationManager.ConnectionStrings["conexaoNorthwind"].ConnectionString;

        static void Main(string[] args)
        {
            //Exemplo1();
            //Exemplo2();
            //Exemplo3();
            //Exemplo4();
            //Exemplo5();
            Exemplo6();
            Console.ReadKey();
        }

        private static void Exemplo6()
        {
            using (var conexaoBD = new SqlConnection(strConexao))
            {
                var atualizarBD = @"Update Products Set UnitPrice = @UnitPrice
                                  Where ProductID = @ProductId";

                conexaoBD.Execute(atualizarBD, new
                {
                    UnitPrice = 99.9m,
                    ProductId = 50
                });

                Console.WriteLine("Informações do fornecedor atualizadas com sucesso.");
            }
        }

        private static void Exemplo5()
        {
            using (var conexaoBD = new SqlConnection(strConexao))
            {
                var fornecedor = new Fornecedor()
                {
                    Address = "Rua Projetada 100",
                    CompanyName = "JcmSoft Inc."
                };

                conexaoBD.Execute(@"insert Suppliers(CompanyName, Address)
                                  values (@CompanyName, @Address)", fornecedor);

                Console.WriteLine("Informações do fornecedor incluídas com sucesso.");
            }
        }

        private static void Exemplo4()
        {
            using (var conexaoBD = new SqlConnection(strConexao))
            {
               var consulta = @"SELECT * FROM dbo.Suppliers WHERE SupplierID = @Id
                              SELECT * FROM dbo.Products WHERE SupplierID = @Id";
                
                using (var resultado = conexaoBD.QueryMultiple(consulta, new { Id = 1 }))
                {
                    var fornecedor = resultado.Read().Single();
                    var produtos = resultado.Read().ToList();

                    Console.WriteLine("Fornecedor  - {0} ", fornecedor.CompanyName);

                    Console.WriteLine(string.Format("Total de Produtos {0}", produtos.Count));
                    foreach (dynamic produto in produtos)
                    {
                        Console.WriteLine("{0} - {1} - {2}", produto.ProductID, produto.ProductName, produto.UnitPrice);
                    }
                }
            }
        }

        private static void Exemplo3()
        {
            using (var conexaoBD = new SqlConnection(strConexao))
            {
                IEnumerable produtos = conexaoBD.Query<Produto>
                    (
                      "Select ProductID, ProductName, UnitPrice from Products Where UnitPrice > @Preco", new { Preco = 40 }
                    );

                Console.WriteLine("{0} - {1} - {2} ", "Código", "Nome do Produto", "Preço do Produto");
                foreach (Produto produto in produtos)
                {
                    Console.WriteLine("{0} - {1} - {2}", produto.ProductID, produto.ProductName, produto.UnitPrice);
                }
            }
        }
       
        private static void Exemplo2()
        {
            using (var conexaoBD = new SqlConnection(strConexao))
            {
                IEnumerable produtos = conexaoBD.Query<Produto>("Select * from Products");

                Console.WriteLine("{0} - {1} - {2} ", "Código", "Nome do Produto", "Preço do Produto");
                foreach (Produto produto in produtos)
                {
                    Console.WriteLine("{0} - {1} - {2}", produto.ProductID, produto.ProductName, produto.UnitPrice);
                }
            }
       }

        private static void Exemplo1()
        {
            SqlConnection conexaoBD = new SqlConnection(strConexao);
            conexaoBD.Open();

            var resultado = conexaoBD.Query("Select * from Customers");

            Console.WriteLine("{0} - {1} - {2} ", "Código", "Nome do Contato", "Endereco do Cliente");
            foreach (dynamic cliente in resultado)
            {
                Console.WriteLine("{0} - {1} - {2} ", cliente.CustomerID, cliente.ContactName, cliente.Address);
            }
            conexaoBD.Close();
        }

    }
}
